# balepy

> balepy Library Python for create bot API in bale application

=> Install and Update:

```python
pip install -U balepy
```

=> START

> doc: github.com/onlyrad

<hr>

# Social Media:
### Rubika: @TheLinux
### Rubika: @Tommy969
